"use strict";
/**
 * GitDocumentDB plugin for remote connection using NodeGit
 * Copyright (c) Hidekazu Kubota
 *
 * This source code is licensed under the Mozilla Public License Version 2.0
 * found in the LICENSE file in the root directory of this source tree.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkHTTP = void 0;
const http_1 = __importDefault(require("http"));
const https_1 = __importDefault(require("https"));
const error_1 = require("./error");
/**
 * Ping to host
 */
/*
export const ping = (
  port: number,
  address: string,
  timeout: number
): Promise<{ ok: boolean; error?: Error }> => {
  return new Promise(resolve => {
    // Create a new tcp socket
    const socket = new Socket();
    // Connect to the given host
    socket.connect(port, address, () => {
      socket.destroy();
      // Resolve with the latency of this attempt
      resolve({ ok: true });
    });
    // Make sure we catch any errors thrown by the socket
    socket.on('error', error => {
      socket.destroy();
      resolve({ ok: false, error });
    });

    socket.setTimeout(timeout, () => {
      socket.destroy();
      resolve({ ok: false, error: new Error('Request timeout') });
    });
  });
};
*/
/**
 * Check HTTP connection
 * @remarks
 * requestTimeout and socketTimeout must be greater than 0.
 * Timeout is not set if timeout is less than 0.
 *
 * @throws {@link Err.HttpProtocolRequiredError}
 * @throws {@link Err.HTTPNetworkError}
 * @throws {@link Err.RequestTimeoutError}
 * @throws {@link Err.SocketTimeoutError}
 *
 * @internal
 */
function checkHTTP(url, requestTimeout, socketTimeout) {
    // timeout must be greater than 0
    socketTimeout !== null && socketTimeout !== void 0 ? socketTimeout : (socketTimeout = requestTimeout);
    if (requestTimeout === 0) {
        requestTimeout = 1;
    }
    if (socketTimeout === 0) {
        socketTimeout = 1;
    }
    return new Promise((resolve, reject) => {
        // Send GET
        let request;
        if (url.startsWith('http:')) {
            request = http_1.default.request;
        }
        else if (url.startsWith('https:')) {
            request = https_1.default.request;
        }
        else {
            reject(new error_1.Err.HttpProtocolRequiredError(url));
        }
        let socket;
        const req = request(url, res => {
            req.removeAllListeners();
            if (socket) {
                socket.removeAllListeners();
            }
            req.destroy();
            resolve({ ok: true, code: res.statusCode });
        });
        req.on('error', error => {
            // network error
            req.removeAllListeners();
            if (socket) {
                socket.removeAllListeners();
            }
            req.destroy();
            reject(new error_1.Err.HTTPNetworkError(error.message));
        });
        if (requestTimeout > 0) {
            req.setTimeout(requestTimeout, () => {
                req.removeAllListeners();
                if (socket) {
                    socket.removeAllListeners();
                }
                req.destroy();
                console.log(' - request timeout error: ' + requestTimeout);
                reject(new error_1.Err.RequestTimeoutError(url));
            });
        }
        if (socketTimeout > 0) {
            req.on('socket', function (mySocket) {
                socket = mySocket;
                socket.setTimeout(socketTimeout);
                socket.on('timeout', () => {
                    req.removeAllListeners();
                    if (socket) {
                        socket.removeAllListeners();
                    }
                    req.destroy();
                    console.log(' - socket timeout error: ' + socketTimeout);
                    reject(new error_1.Err.SocketTimeoutError(url));
                });
            });
        }
        req.end();
    });
}
exports.checkHTTP = checkHTTP;
//# sourceMappingURL=net.js.map