/**
 * GitDocumentDB plugin for remote connection using NodeGit
 * Copyright (c) Hidekazu Kubota
 *
 * This source code is licensed under the Mozilla Public License Version 2.0
 * found in the LICENSE file in the root directory of this source tree.
 */
import { Logger } from 'tslog';
import { RemoteOptions } from './types';
export declare function sleep(msec: number): Promise<unknown>;
declare const type = "remote";
/**
 * Clone
 *
 * @throws {@link Err.CannotConnectError}
 * @throws {@link Err.CannotCloneRepositoryError}
 */
declare function clone(workingDir: string, remoteOptions: RemoteOptions, logger?: Logger): Promise<void>;
/**
 * Check connection by FETCH
 *
 * @throws {@link Err.InvalidURLError}
 * @throws {@link Err.RemoteRepositoryNotFoundError}
 * @throws Error (Other errors from NodeGit.Remote#connect())
 *
 * @internal
 */
declare function checkFetch(workingDir: string, options: RemoteOptions, logger?: Logger): Promise<'exist' | 'not_exist'>;
/**
 * Check connection by PUSH
 *
 * @throws {@link Err.InvalidURLError}
 * @throws {@link Err.RemoteRepositoryNotFoundError}
 * @throws {@link Err.PushPermissionDeniedError}
 * @throws Error (Other errors from NodeGit.Remote#connect())
 *
 * @internal
 */
declare function checkPush(workingDir: string, options: RemoteOptions, logger?: Logger): Promise<string>;
/**
 * Calc distance
 */
export declare function calcDistance(baseCommitOid: string, localCommitOid: string, remoteCommitOid: string): {
    ahead: undefined;
    behind: undefined;
} | {
    ahead: number;
    behind: number;
};
/**
 * git push
 *
 * @throws {@link Err.UnfetchedCommitExistsError} (from this and validatePushResult())
 * @throws {@link Err.SyncWorkerFetchError} (from validatePushResult())
 * @throws {@link Err.GitPushError} (from NodeGit.Remote.push())
 */
declare function push(workingDir: string, remoteOptions: RemoteOptions): Promise<void>;
/**
 * git fetch
 *
 * @throws {@link Err.SyncWorkerFetchError}
 */
declare function fetch(workingDir: string, remoteOptions: RemoteOptions, logger?: Logger): Promise<void>;
export { checkFetch, checkPush, clone, fetch, push, type };
//# sourceMappingURL=remote-nodegit.d.ts.map